/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.callbacks;



import java.awt.Color;
import java.awt.Graphics2D;



import org.gfxtest.framework.TestImage;



/**
 * Class representing set of callback methods called for each rendered circle.
 * 
 * @author Pavel Tisnovsky
 */
public abstract class CommonCircleDrawCallbacks extends CommonCallbacks
{
    /**
     * Setup phase. @see CommonCallbacks#setup(TestImage, Graphics2D)
     * 
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    @Override
    public void setup(TestImage image, Graphics2D graphics)
    {
        this.image = image;
        this.graphics = graphics;
        // set drawing color
        graphics.setColor(Color.BLACK);
    }

    /**
     * This method is called for each rendered circle.
     * 
     * @param x
     *            horizontal coordinate of a circle center
     * @param y
     *            vertical coordinate of a circle center
     * @param radius
     *            circle radius (might be different for each rendered circle)
     * @param maxRadius
     *            maximum allowable circle radius
     * @param colorIndex 
     *            color index
     */
    public abstract void iterationCallBack(int x, int y, int radius, int maxRadius, int colorIndex);

    /**
     * Cleanup phase. {@see CommonCallbacks#cleanup()}
     */
    @Override
    public void cleanup()
    {
        return;
    }
}
