/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.framework.annotations;



/**
 * Names of graphics primitives used for annotation of each test suite.
 * @see GraphicsPrimitive
 * 
 * @author Pavel Tisnovsky
 */
public enum GraphicsPrimitives
{
    /**
     * Raster image.
     */
    COMMON_BITMAP,

    /**
     * Line segment in (x, y) coordinate space.
     */
    LINE,

    /**
     * Rectangle defined by a location (x, y) and dimension (w x h).
     */
    RECTANGLE,

    /**
     * Rectangle with rounded corners defined by a location (x, y), a dimension
     * (w x h), and the width and height of the corner arc.
     */
    ROUND_RECTANGLE,

    /**
     * Rectangle with "3d shade" defined by a location (x, y) and dimension (w x
     * h).
     */
    THREE_D_RECTANGLE,

    /**
     * Sequence of connected lines defined as general path.
     */
    POLYLINE,

    /**
     * Closed sequence of connected lines defined as general path.
     */
    POLYGON,

    /**
     * Circular or elliptical arc covering the specified rectangle.
     */
    ARC,

    /**
     * Circle defined by a bounding square (special case of ellipse).
     */
    CIRCLE,

    /**
     * Ellipse defined by a bounding rectangle.
     */
    ELLIPSE,

    /**
     * Generic path consisting of line segments, quadratic curves and cubic curves.
     */
    PATH,

    /**
     * Generic shape consisting of line segment, quadratic curve, cubic curve etc.
     */
    SHAPE,

    /**
     * Generic area, ie. closed shape.
     */
    AREA,

    /**
     * Text with various styles.
     */
    TEXT,
}
